/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tARCH = 258,
     tAS = 259,
     tAUTOMOUNT = 260,
     tCLUSTER = 261,
     tCONFIG = 262,
     tDUMPSET = 263,
     tEQ = 264,
     tNFSEQ = 265,
     tEXPORTFS = 266,
     tFREQ = 267,
     tFROM = 268,
     tFS = 269,
     tFSTYPE = 270,
     tHWADDR = 271,
     tINADDR = 272,
     tHOST = 273,
     tLOCALHOST = 274,
     tLOG = 275,
     tMOUNT = 276,
     tNETMASK = 277,
     tNETIF = 278,
     tVOLNAME = 279,
     tOPTS = 280,
     tOS = 281,
     tPASSNO = 282,
     tDIRECT = 283,
     tSEL = 284,
     tSTR = 285
   };
#endif
#define tARCH 258
#define tAS 259
#define tAUTOMOUNT 260
#define tCLUSTER 261
#define tCONFIG 262
#define tDUMPSET 263
#define tEQ 264
#define tNFSEQ 265
#define tEXPORTFS 266
#define tFREQ 267
#define tFROM 268
#define tFS 269
#define tFSTYPE 270
#define tHWADDR 271
#define tINADDR 272
#define tHOST 273
#define tLOCALHOST 274
#define tLOG 275
#define tMOUNT 276
#define tNETMASK 277
#define tNETIF 278
#define tVOLNAME 279
#define tOPTS 280
#define tOS 281
#define tPASSNO 282
#define tDIRECT 283
#define tSEL 284
#define tSTR 285




/* Copy the first part of user declarations.  */
#line 44 "../../fsinfo/fsi_gram.y"

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */
#include <am_defs.h>
#include <fsi_data.h>
#include <fsinfo.h>

extern qelem *list_of_hosts, *list_of_automounts;


/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 55 "../../fsinfo/fsi_gram.y"
typedef union YYSTYPE {
	auto_tree *a;
	disk_fs *d;
	ether_if *e;
	host *h;
	qelem *q;
	char *s;
	fsi_mount *m;
	fsmount *f;
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 157 "fsi_gram.c"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 169 "fsi_gram.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   122

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  34
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  16
/* YYNRULES -- Number of rules. */
#define YYNRULES  57
/* YYNRULES -- Number of states. */
#define YYNSTATES  124

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   285

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    33,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    31,     2,    32,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char yyprhs[] =
{
       0,     0,     3,     4,     7,    10,    15,    21,    23,    28,
      29,    36,    40,    45,    50,    55,    60,    61,    66,    71,
      76,    80,    83,    84,    87,    88,    91,    97,   101,   102,
     107,   112,   117,   122,   126,   131,   136,   141,   142,   148,
     154,   159,   166,   167,   174,   175,   179,   183,   187,   192,
     193,   198,   199,   202,   206,   210,   214,   218
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      35,     0,    -1,    -1,    35,    36,    -1,    35,    40,    -1,
      18,    37,    42,    48,    -1,     1,    18,    37,    42,    48,
      -1,    30,    -1,    31,    38,    32,    30,    -1,    -1,    38,
      23,    30,    31,    39,    32,    -1,    38,     7,    30,    -1,
      38,     3,    33,    30,    -1,    38,    26,    33,    30,    -1,
      38,     6,    33,    30,    -1,    38,     1,    33,    30,    -1,
      -1,    39,    17,    33,    30,    -1,    39,    22,    33,    30,
      -1,    39,    16,    33,    30,    -1,     5,    41,    45,    -1,
       5,     1,    -1,    -1,    25,    30,    -1,    -1,    42,    43,
      -1,    14,    30,    31,    44,    32,    -1,    14,     1,    32,
      -1,    -1,    44,    15,    33,    30,    -1,    44,    25,    33,
      30,    -1,    44,    27,    33,    30,    -1,    44,    12,    33,
      30,    -1,    44,    21,    46,    -1,    44,     8,    33,    30,
      -1,    44,    20,    33,    30,    -1,    44,     1,    33,    30,
      -1,    -1,    45,    30,    41,    33,    30,    -1,    45,    30,
      41,    10,    30,    -1,    45,    30,     9,    30,    -1,    45,
      30,    41,    31,    45,    32,    -1,    -1,    46,    30,    31,
      47,    46,    32,    -1,    -1,    47,    11,    30,    -1,    47,
      24,    30,    -1,    47,    29,    30,    -1,    47,     1,    33,
      30,    -1,    -1,    48,    21,    30,    49,    -1,    -1,    49,
      28,    -1,    49,     4,    30,    -1,    49,    13,    30,    -1,
      49,    15,    30,    -1,    49,    25,    30,    -1,    49,     1,
      33,    30,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,   111,   111,   113,   117,   128,   131,   137,   140,   147,
     149,   155,   158,   161,   164,   167,   173,   175,   177,   179,
     189,   197,   203,   205,   211,   213,   232,   235,   252,   254,
     257,   260,   263,   266,   269,   272,   275,   290,   292,   302,
     313,   323,   337,   339,   354,   356,   359,   362,   365,   376,
     378,   399,   401,   404,   407,   410,   413,   416
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "tARCH", "tAS", "tAUTOMOUNT", "tCLUSTER", 
  "tCONFIG", "tDUMPSET", "tEQ", "tNFSEQ", "tEXPORTFS", "tFREQ", "tFROM", 
  "tFS", "tFSTYPE", "tHWADDR", "tINADDR", "tHOST", "tLOCALHOST", "tLOG", 
  "tMOUNT", "tNETMASK", "tNETIF", "tVOLNAME", "tOPTS", "tOS", "tPASSNO", 
  "tDIRECT", "tSEL", "tSTR", "'{'", "'}'", "'='", "$accept", 
  "list_of_hosts", "host", "host_attr", "host_attr_list", "ether_attr", 
  "automount", "opt_auto_opts", "list_of_filesystems", "filesystem", 
  "fs_info_list", "automount_tree", "dir_tree", "dir_tree_info", 
  "list_of_mounts", "localinfo_list", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   123,   125,    61
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    34,    35,    35,    35,    36,    36,    37,    37,    38,
      38,    38,    38,    38,    38,    38,    39,    39,    39,    39,
      40,    40,    41,    41,    42,    42,    43,    43,    44,    44,
      44,    44,    44,    44,    44,    44,    44,    45,    45,    45,
      45,    45,    46,    46,    47,    47,    47,    47,    47,    48,
      48,    49,    49,    49,    49,    49,    49,    49
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     0,     2,     2,     4,     5,     1,     4,     0,
       6,     3,     4,     4,     4,     4,     0,     4,     4,     4,
       3,     2,     0,     2,     0,     2,     5,     3,     0,     4,
       4,     4,     4,     3,     4,     4,     4,     0,     5,     5,
       4,     6,     0,     6,     0,     3,     3,     3,     4,     0,
       4,     0,     2,     3,     3,     3,     3,     4
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       2,     0,     1,     0,     0,     0,     3,     4,     0,    21,
       0,    37,     7,     9,    24,    24,    23,    20,     0,    49,
      49,    22,     0,     0,     0,     0,     0,     0,     0,     0,
      25,     5,     6,     0,     0,     0,     0,     0,    11,     0,
       0,     8,     0,     0,     0,    40,     0,    37,     0,    15,
      12,    14,    16,    13,    27,    28,    51,    39,     0,    38,
       0,     0,     0,    41,     0,     0,     0,    10,     0,     0,
       0,     0,     0,    42,     0,     0,    26,     0,     0,     0,
       0,     0,    52,     0,     0,     0,     0,     0,     0,     0,
       0,    33,     0,     0,     0,    53,    54,    55,    56,    19,
      17,    18,    36,    34,    32,    29,    35,     0,    30,    31,
      57,    44,     0,     0,     0,     0,     0,     0,     0,    45,
      46,    47,    43,    48
};

/* YYDEFGOTO[NTERM-NUM]. */
static const yysigned_char yydefgoto[] =
{
      -1,     1,     6,    14,    18,    60,     7,    11,    19,    30,
      61,    17,    91,   112,    31,    62
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -36
static const yysigned_char yypact[] =
{
     -36,    46,   -36,    -8,    32,   -14,   -36,   -36,   -14,   -36,
     -26,   -36,   -36,   -36,   -36,   -36,   -36,     6,     2,    28,
      28,    -7,    12,    23,    25,    29,    30,    34,    35,     0,
     -36,    47,    47,    40,    -4,    41,    42,    44,   -36,    24,
      45,   -36,    49,    51,    50,   -36,    53,   -36,    54,   -36,
     -36,   -36,   -36,   -36,   -36,   -36,   -36,   -36,   -17,   -36,
      22,    -1,    48,   -36,    52,    55,    56,   -36,    57,    58,
      59,    60,    61,   -36,    62,    63,   -36,    64,    68,    69,
      70,    71,   -36,    72,    73,    74,    75,    76,    77,    78,
      79,    80,    81,    82,    83,   -36,   -36,   -36,   -36,   -36,
     -36,   -36,   -36,   -36,   -36,   -36,   -36,    84,   -36,   -36,
     -36,   -36,    11,    85,    86,    87,    89,    -9,    90,   -36,
     -36,   -36,   -36,   -36
};

/* YYPGOTO[NTERM-NUM].  */
static const yysigned_char yypgoto[] =
{
     -36,   -36,   -36,   106,   -36,   -36,   -36,    65,   107,   -36,
     -36,    31,   -35,   -36,    67,   -36
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -51
static const yysigned_char yytable[] =
{
      68,    42,    33,    22,    16,    23,    46,    69,    24,    25,
       8,    70,   113,    21,    71,    63,    12,    13,    10,    72,
      73,   107,   114,   122,    74,    26,    75,    47,    27,    48,
      43,    76,   -22,     9,    28,   115,    21,   -22,    64,    65,
     116,   -42,    29,   -42,    66,    35,     2,     3,   -50,    77,
     -22,     4,    78,   -50,    67,    52,    36,    10,    37,    38,
      39,    79,   -22,    80,     5,    41,   -50,    40,    44,   -50,
      45,    49,    50,    81,    51,    53,    82,   117,    58,     0,
      56,    54,    55,    57,    59,    83,    34,    32,    84,    85,
      86,    87,    88,    89,    90,    92,    93,    94,    95,    96,
      97,    98,    99,   100,   101,   102,   103,   104,   105,   106,
     107,   108,   109,   110,    15,   111,   119,   120,   118,   121,
     123,     0,    20
};

static const yysigned_char yycheck[] =
{
       1,     1,     9,     1,    30,     3,    10,     8,     6,     7,
      18,    12,     1,    30,    15,    32,    30,    31,    25,    20,
      21,    30,    11,    32,    25,    23,    27,    31,    26,    33,
      30,    32,     0,     1,    32,    24,    30,     5,    16,    17,
      29,    30,    14,    32,    22,    33,     0,     1,     0,     1,
      18,     5,     4,     5,    32,    31,    33,    25,    33,    30,
      30,    13,    30,    15,    18,    30,    18,    33,    21,    21,
      30,    30,    30,    25,    30,    30,    28,   112,    47,    -1,
      30,    32,    31,    30,    30,    33,    21,    20,    33,    33,
      33,    33,    33,    33,    33,    33,    33,    33,    30,    30,
      30,    30,    30,    30,    30,    30,    30,    30,    30,    30,
      30,    30,    30,    30,     8,    31,    30,    30,    33,    30,
      30,    -1,    15
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,    35,     0,     1,     5,    18,    36,    40,    18,     1,
      25,    41,    30,    31,    37,    37,    30,    45,    38,    42,
      42,    30,     1,     3,     6,     7,    23,    26,    32,    14,
      43,    48,    48,     9,    41,    33,    33,    33,    30,    30,
      33,    30,     1,    30,    21,    30,    10,    31,    33,    30,
      30,    30,    31,    30,    32,    31,    30,    30,    45,    30,
      39,    44,    49,    32,    16,    17,    22,    32,     1,     8,
      12,    15,    20,    21,    25,    27,    32,     1,     4,    13,
      15,    25,    28,    33,    33,    33,    33,    33,    33,    33,
      33,    46,    33,    33,    33,    30,    30,    30,    30,    30,
      30,    30,    30,    30,    30,    30,    30,    30,    30,    30,
      30,    31,    47,     1,    11,    24,    29,    46,    33,    30,
      30,    30,    32,    30
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1

/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylineno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylineno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  
  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
#line 111 "../../fsinfo/fsi_gram.y"
    { yyval.q = new_que(); }
    break;

  case 3:
#line 114 "../../fsinfo/fsi_gram.y"
    { if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
	    yyval.q = yyvsp[-1].q; }
    break;

  case 4:
#line 118 "../../fsinfo/fsi_gram.y"
    { if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
	    yyval.q = yyvsp[-1].q; }
    break;

  case 5:
#line 129 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
    break;

  case 6:
#line 132 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
    break;

  case 7:
#line 138 "../../fsinfo/fsi_gram.y"
    { yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); }
    break;

  case 8:
#line 141 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); }
    break;

  case 9:
#line 147 "../../fsinfo/fsi_gram.y"
    { yyval.h = new_host(); }
    break;

  case 10:
#line 150 "../../fsinfo/fsi_gram.y"
    { if (yyvsp[-1].e) {
		yyvsp[-1].e->e_if = yyvsp[-3].s;
		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
	  }
    break;

  case 11:
#line 156 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); }
    break;

  case 12:
#line 159 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); }
    break;

  case 13:
#line 162 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); }
    break;

  case 14:
#line 165 "../../fsinfo/fsi_gram.y"
    { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); }
    break;

  case 15:
#line 168 "../../fsinfo/fsi_gram.y"
    { yyerror("unknown host attribute"); }
    break;

  case 16:
#line 173 "../../fsinfo/fsi_gram.y"
    { yyval.e = new_ether_if(); }
    break;

  case 17:
#line 176 "../../fsinfo/fsi_gram.y"
    { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); }
    break;

  case 18:
#line 178 "../../fsinfo/fsi_gram.y"
    { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); }
    break;

  case 19:
#line 180 "../../fsinfo/fsi_gram.y"
    { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); }
    break;

  case 20:
#line 190 "../../fsinfo/fsi_gram.y"
    { if (yyvsp[0].q) {
		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
	    } else {
		yyval.a = 0;
	    }
	  }
    break;

  case 21:
#line 198 "../../fsinfo/fsi_gram.y"
    { yyval.a = 0; }
    break;

  case 22:
#line 203 "../../fsinfo/fsi_gram.y"
    { yyval.s = strdup(""); }
    break;

  case 23:
#line 206 "../../fsinfo/fsi_gram.y"
    { yyval.s = yyvsp[0].s; }
    break;

  case 24:
#line 211 "../../fsinfo/fsi_gram.y"
    { yyval.q = 0; }
    break;

  case 25:
#line 214 "../../fsinfo/fsi_gram.y"
    { if (yyvsp[0].d) {
		if (yyvsp[-1].q)
			yyval.q = yyvsp[-1].q;
		else
			yyval.q = new_que();
		ins_que(&yyvsp[0].d->d_q, yyval.q->q_back);
	    } else {
		yyval.q = yyvsp[-1].q;
	    }
	  }
    break;

  case 26:
#line 233 "../../fsinfo/fsi_gram.y"
    { yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; }
    break;

  case 27:
#line 236 "../../fsinfo/fsi_gram.y"
    { yyval.d = (disk_fs *) NULL; }
    break;

  case 28:
#line 252 "../../fsinfo/fsi_gram.y"
    { yyval.d = new_disk_fs(); }
    break;

  case 29:
#line 255 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); }
    break;

  case 30:
#line 258 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); }
    break;

  case 31:
#line 261 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); }
    break;

  case 32:
#line 264 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); }
    break;

  case 33:
#line 267 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); }
    break;

  case 34:
#line 270 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); }
    break;

  case 35:
#line 273 "../../fsinfo/fsi_gram.y"
    { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); }
    break;

  case 36:
#line 276 "../../fsinfo/fsi_gram.y"
    { yyerror("unknown filesystem attribute"); }
    break;

  case 37:
#line 290 "../../fsinfo/fsi_gram.y"
    { yyval.q = 0; }
    break;

  case 38:
#line 293 "../../fsinfo/fsi_gram.y"
    { automount *a = new_automount(yyvsp[-3].s);
	    a->a_volname = yyvsp[0].s;
	    a->a_opts = yyvsp[-2].s;
	    if (yyvsp[-4].q)
		yyval.q = yyvsp[-4].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  }
    break;

  case 39:
#line 303 "../../fsinfo/fsi_gram.y"
    { automount *a = new_automount(yyvsp[-3].s);
            a->a_hardwiredfs = yyvsp[0].s;
            a->a_opts = yyvsp[-2].s;
            if (yyvsp[-4].q)
                yyval.q = yyvsp[-4].q;
            else
                yyval.q = new_que();
            ins_que(&a->a_q, yyval.q->q_back);
          }
    break;

  case 40:
#line 314 "../../fsinfo/fsi_gram.y"
    { automount *a = new_automount(yyvsp[-2].s);
	    a->a_symlink = yyvsp[0].s;
	    if (yyvsp[-3].q)
		yyval.q = yyvsp[-3].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  }
    break;

  case 41:
#line 324 "../../fsinfo/fsi_gram.y"
    { automount *a = new_automount(yyvsp[-4].s);
	    a->a_mount = yyvsp[-1].q;
	    a->a_opts = yyvsp[-3].s;
	    if (yyvsp[-5].q)
		yyval.q = yyvsp[-5].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  }
    break;

  case 42:
#line 337 "../../fsinfo/fsi_gram.y"
    { yyval.q = 0; }
    break;

  case 43:
#line 340 "../../fsinfo/fsi_gram.y"
    { yyvsp[-2].m->m_mount = yyvsp[-1].q;
	    yyvsp[-2].m->m_name = yyvsp[-4].s;
	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
		yyerror("not allowed '/' in a directory name");
	    if (yyvsp[-5].q)
		yyval.q = yyvsp[-5].q;
	    else
		yyval.q = new_que();
	    ins_que(&yyvsp[-2].m->m_q, yyval.q->q_back);
	  }
    break;

  case 44:
#line 354 "../../fsinfo/fsi_gram.y"
    { yyval.m = new_mount(); }
    break;

  case 45:
#line 357 "../../fsinfo/fsi_gram.y"
    { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); }
    break;

  case 46:
#line 360 "../../fsinfo/fsi_gram.y"
    { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); }
    break;

  case 47:
#line 363 "../../fsinfo/fsi_gram.y"
    { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); }
    break;

  case 48:
#line 366 "../../fsinfo/fsi_gram.y"
    { yyerror("unknown directory attribute"); }
    break;

  case 49:
#line 376 "../../fsinfo/fsi_gram.y"
    { yyval.q = 0; }
    break;

  case 50:
#line 379 "../../fsinfo/fsi_gram.y"
    { set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
	    if (yyvsp[-3].q)
		yyval.q = yyvsp[-3].q;
	    else
		yyval.q = new_que();
	    ins_que(&yyvsp[0].f->f_q, yyval.q->q_back);
	    }
    break;

  case 51:
#line 399 "../../fsinfo/fsi_gram.y"
    { yyval.f = new_fsmount(); }
    break;

  case 52:
#line 402 "../../fsinfo/fsi_gram.y"
    { yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); }
    break;

  case 53:
#line 405 "../../fsinfo/fsi_gram.y"
    { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); }
    break;

  case 54:
#line 408 "../../fsinfo/fsi_gram.y"
    { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); }
    break;

  case 55:
#line 411 "../../fsinfo/fsi_gram.y"
    { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); }
    break;

  case 56:
#line 414 "../../fsinfo/fsi_gram.y"
    { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); }
    break;

  case 57:
#line 417 "../../fsinfo/fsi_gram.y"
    { yyerror("unknown mount attribute"); }
    break;


    }

/* Line 991 of yacc.c.  */
#line 1491 "fsi_gram.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  char *yymsg;
	  int yyx, yycount;

	  yycount = 0;
	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  for (yyx = yyn < 0 ? -yyn : 0;
	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
	  yysize += yystrlen ("syntax error, unexpected ") + 1;
	  yysize += yystrlen (yytname[yytype]);
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yycount = 0;
		  for (yyx = yyn < 0 ? -yyn : 0;
		       yyx < (int) (sizeof (yytname) / sizeof (char *));
		       yyx++)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			const char *yyq = ! yycount ? ", expecting " : " or ";
			yyp = yystpcpy (yyp, yyq);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yycount++;
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab2;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:

  /* Suppress GCC warning that yyerrlab1 is unused when no action
     invokes YYERROR.  */
#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__) \
    && !defined __cplusplus
  __attribute__ ((__unused__))
#endif


  goto yyerrlab2;


/*---------------------------------------------------------------.
| yyerrlab2 -- pop states until the error token can be shifted.  |
`---------------------------------------------------------------*/
yyerrlab2:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}



